package com.parseSystem.event;

import com.dragon.common.redis.service.RedisService;
import com.parseSystem.utils.SpringUtils;
import com.parseSystem.vehicle.VehicleData;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * 事件处理接口
 *
 * @author 冯凯
 * @version 1.0
 * @description:
 * @date 2023/11/27 20:54
 */
@Component
@Log4j2
public class EventHandlerService {

    /**
     * 事件处理map
     */
    public static final Map<String, List<String>> eventMap = new ConcurrentHashMap<>();
    @Autowired
    private RedisService redisService;

    /**
     * 注册事件
     *
     * @param vin
     * @param eventServiceName
     */
    public void registerEvent(String vin, String eventServiceName) {
        getEventList(vin).add(eventServiceName);
    }

    /**
     * 移除事件
     *
     * @param vin
     * @param eventServiceName
     */
    public void removeEvent(String vin, String eventServiceName) {
        getEventList(vin).remove(eventServiceName);
    }

    /**
     * 执行事件
     *
     * @param vehicleData
     */
    public void executeEvent(VehicleData vehicleData) {
        List<String> eventList = getEventList(vehicleData.getVin());
        eventList.forEach(eventServiceName -> {
            VehicleEventService vehicleEventService = SpringUtils.getBean(eventServiceName);
            vehicleEventService.executeEvent(vehicleData);
        });
    }

    /**
     * 获取事件列表
     *
     * @param vin
     * @return
     */
    public List<String> getEventList(String vin) {
        List<String> cacheList = redisService.getCacheList("event_VIN123456789");
        eventMap.put(vin, cacheList);
        List<String> eventList = eventMap.get(vin);
        if (eventList == null) {
            ArrayList<String> list = new ArrayList<>();
            eventMap.put(vin, list);
        }
        return eventList;
    }
}
