package com.parseSystem.utils;

import com.parseSystem.storage.service.StorageDateService;
import com.parseSystem.vehicle.VehicleData;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.BlockingQueue;

/**
 * @author 冯凯
 * @version 1.0
 * @description:
 * @date 2023/12/1 20:47
 */
@Component
@Log4j2
public class DataQueueManager {

    private int count;
    @Autowired
    private StorageDateService storageDateService;


    @Autowired
    private BlockingQueue<VehicleData> dataQueue1;

    @Autowired
    private BlockingQueue<VehicleData> dataQueue2;



    public void enqueueData(VehicleData vehicleData) {
        // 将数据放入第一个队列中，如果已满，则放入第二个队列中
        if (!dataQueue1.offer(vehicleData)) {
            log.warn("第一个队列已满，将数据放入第二个队列");
            dataQueue2.offer(vehicleData);
        }

    }


    @Scheduled(fixedRate = 5000)
    public void processQueues() {
        // 如果第一个队列中的数据数量达到阈值，就从第一个队列中取出数据进行批量持久化操作
        if (!dataQueue1.isEmpty()) {

            List<VehicleData> batchData = new ArrayList<>();
            count+=batchData.size();
            dataQueue1.drainTo(batchData);
            storageDateService.saveBatch(batchData);
        }
        // 如果第一个队列为空，但是第二个队列不为空，就从第二个队列中取出数据进行持久化操作
        else if (dataQueue1.isEmpty() && !dataQueue2.isEmpty()) {
            log.warn("第一个队列为空，从第二个队列中取出数据进行持久化操作");
            List<VehicleData> batchData = new ArrayList<>();
            count+=batchData.size();
            dataQueue2.drainTo(batchData);
            storageDateService.saveBatch(batchData);
        }

    }

}
