package com.parseSystem.vehicle;


import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.*;

import java.math.BigDecimal;
import java.util.Date;

@Data
@Builder
@ToString
@NoArgsConstructor
@AllArgsConstructor
@TableName("vehicle_data_copy1")
public class VehicleData {

    /**
     * 主键id
     */
    @TableId(type = IdType.AUTO)
    private Integer id;

    /**
     * VIN
     */
    private String vin;

    /**
     * 时间戳
     */
    private Date createTime;

    /**
     * 经度
     */
    private String longitude;

    /**
     * 维度
     */
    private String latitude;

    /**
     * 速度
     */
    private String speed;

    /**
     * 里程
     */
    private BigDecimal mileage;

    /**
     * 总电压
     */
    private String voltage;

    /**
     * 总电流
     */
    private String current;

    /**
     * 绝缘电阻
     */
    private String resistance;

    /**
     * 档位
     */
    private String gear;

    /**
     * 加速踏板行程值
     */
    private String accelerationPedal;

    /**
     * 制动踏板行程值
     */
    private String brakePedal;

    /**
     * 燃料消耗率
     */
    private String fuelConsumptionRate;

    /**
     * 电机控制器温度
     */
    private String motorControllerTemperature;

    /**
     * 电机转速
     */
    private String motorSpeed;

    /**
     * 电机转矩
     */
    private String motorTorque;

    /**
     * 电机温度
     */
    private String motorTemperature;

    /**
     * 电机电压
     */
    private String motorVoltage;

    /**
     * 电机电流
     */
    private String motorCurrent;

    /**
     * 动力电池剩余电量SOC
     */
    private BigDecimal remainingBattery;


    /**
     * 当前状态允许的最大反馈功率
     */
    private String maximumFeedbackPower;

    /**
     * 当前状态允许最大放电功率
     */
    private String maximumDischargePower;

    /**
     * BMS自检计数器
     */
    private String selfCheckCounter;

    /**
     * 动力电池充放电电流
     */
    private String totalBatteryCurrent;

    /**
     * 动力电池负载端总电压V3
     */
    private String totalBatteryVoltage;

    /**
     * 单次最大电压
     */
    private String singleBatteryMaxVoltage;

    /**
     * 单体电池最低电压
     */
    private String singleBatteryMinVoltage;

    /**
     * 单体电池最高温度
     */
    private String singleBatteryMaxTemperature;

    /**
     * 单体电池最低温度
     */
    private String singleBatteryMinTemperature;

    /**
     * 动力电池可用容量
     */
    private String availableBatteryCapacity;

    /**
     * 车辆状态
     */
    private int vehicleStatus;

    /**
     * 充电状态
     */
    private int chargingStatus;

    /**
     * 运行状态
     */
    private int operatingStatus;

    /**
     * SOC
     */
    private int socStatus;

    /**
     * 可充电储能装置工作状态
     */
    private int chargingEnergyStorageStatus;

    /**
     * 驱动电机状态
     */
    private int driveMotorStatus;

    /**
     * 定位是否有效
     */
    private int positionStatus;

    /**
     * EAS(汽车防盗系统)状态
     */
    private int easStatus;

    /**
     * PTC(电动加热器)状态
     */
    private int ptcStatus;

    /**
     * EPS(电动助力系统)状态
     */
    private int epsStatus;

    /**
     * ABS(防抱死)状态
     */
    private int absStatus;

    /**
     * MCU(电机/逆变器)状态
     */
    private int mcuStatus;

    /**
     * 动力电池加热状态
     */
    private int heatingStatus;

    /**
     * 动力电池当前状态
     */
    private int batteryStatus;

    /**
     * 动力电池保温状态
     */
    private int batteryInsulationStatus;


    public static VehicleData getBuild(String messages) {
        char start = messages.charAt(0);
        char end = messages.charAt(messages.length() - 1);
        System.out.println(start);
        System.out.println(end);
        return VehicleData.builder()
                .vin(messages.substring(1, 18))
                //messages.substring(18, 31)
                .createTime(new Date())
                .longitude(messages.substring(31, 42))
                .latitude(messages.substring(42, 52))
                .speed(messages.substring(52, 58))
                .mileage(new BigDecimal(messages.substring(58, 69)))
                .voltage(messages.substring(69, 75))
                .current(messages.substring(75, 80))
                .resistance(messages.substring(80, 89))
                .gear(messages.substring(89, 90))
                .accelerationPedal(messages.substring(90, 92))
                .brakePedal(messages.substring(92, 94))
                .fuelConsumptionRate(messages.substring(94, 99))
                .motorControllerTemperature(messages.substring(99, 105))
                .motorSpeed(messages.substring(105, 110))
                .motorTorque(messages.substring(110, 114))
                .motorTemperature(messages.substring(114, 120))
                .motorVoltage(messages.substring(120, 125))
                .motorCurrent(messages.substring(125, 133))
                .remainingBattery(new BigDecimal(messages.substring(133, 139)))
                .maximumFeedbackPower(messages.substring(139, 145))
                .maximumDischargePower(messages.substring(145, 151))
                .selfCheckCounter(messages.substring(151, 153))
                .totalBatteryCurrent(messages.substring(153, 158))
                .totalBatteryVoltage(messages.substring(158, 164))
                .singleBatteryMaxVoltage(messages.substring(164, 168))
                .singleBatteryMinVoltage(messages.substring(168, 172))
                .singleBatteryMaxTemperature(messages.substring(172, 178))
                .singleBatteryMinTemperature(messages.substring(178, 184))
                .availableBatteryCapacity(messages.substring(184, 190))
                .vehicleStatus(Integer.valueOf(messages.substring(190, 191)))
                .chargingStatus(Integer.valueOf(messages.substring(191, 192)))
                .operatingStatus(Integer.valueOf(messages.substring(192, 193)))
                .socStatus(Integer.valueOf(messages.substring(193, 194)))
                .chargingEnergyStorageStatus(Integer.valueOf(messages.substring(194, 195)))
                .driveMotorStatus(Integer.valueOf(messages.substring(195, 196)))
                .positionStatus(Integer.valueOf(messages.substring(196, 197)))
                .easStatus(Integer.valueOf(messages.substring(197, 198)))
                .ptcStatus(Integer.valueOf(messages.substring(198, 199)))
                .epsStatus(Integer.valueOf(messages.substring(199, 200)))
                .absStatus(Integer.valueOf(messages.substring(200, 201)))
                .mcuStatus(Integer.valueOf(messages.substring(201, 202)))
                .heatingStatus(Integer.valueOf(messages.substring(202, 203)))
                .batteryStatus(Integer.valueOf(messages.substring(203, 204)))
                .batteryInsulationStatus(Integer.valueOf(messages.substring(204, 205)))
                .build();

    }
}
